#!/usr/bin/env python
# Copyright 2008-2009 David D Lowe
# released under the GPLv3

from __future__ import division
from pigment import PigmentType, Pigment
from pigment_more import DirBasedPigment, DirBasedPigmentType
import pigment
import os, sys
import gconf
import subprocess
from glob import glob
if __name__ == "__main__" or 'pychecker' in sys.argv[0]:
    sys.path.append("..")
import ep_exceptions
import handy
import hashlib
from gettext import gettext as _


class IconsType(DirBasedPigmentType):
    humanName = {"en":"Icons"}
    humanPluralName = {"en":"Icons"}
    codeName = "icons"
    abbreviation = "ic"
    directoryName = "icons"
    canGeneratePreview = True
    
    attachmentTypeHelp = _("The theme file should be a directory that contains many others including one of 8x8, 12x12, 16x16, 22x22, 24x24, 32x32, 48x48, 64x64 and scalable,  and that does not contain a cursors directory")
        
    isDirectoryShared = True
    specificChildren = ("8x8", "12x12", "16x16", "22x22", "24x24", "32x32", "48x48", "64x64", "scalable", "index.theme", "icon-theme.cache",\
        "actions","animations","apps","categories","devices","emblems","mimes","places","status","stock")

    def get_Pigment(self):
        return Icons

    publicBaseDir = "/usr/share/icons"
    personalBaseDir = "~/.icons"


class Icons(DirBasedPigment):
    
    def __init__(self):
        DirBasedPigment.__init__(self)
        self.type = IconsType()

    def activate(self, progressCallback=None, shell=None):
        if progressCallback is None:
            progressCallback = lambda(a1): False
        if progressCallback(0.0): return
        client = gconf.client_get_default()
        client.set_string("/desktop/gnome/interface/icon_theme", self.attDirname)
        progressCallback(1.0)
    
    def is_activated(self):
        """Returns whether this pigment is applied. To check if the effects
        have been activated regardless of Epidermis' pigments, use is_meat_activated"""
        return self.is_meat_activated()

    def is_attachment_correct(self, attachmentIndex=None):
        if not DirBasedPigment.is_attachment_correct(self, attachmentIndex):
            return False
        if attachmentIndex is None: att = self.attachments[0]
        else: att = self.attachments[attachmentIndex]
        foundOne = False
        for folderName in ("8x8", "12x12", "16x16", "22x22", "24x24", "32x32", "48x48",
            "64x64", "scalable"):
            if os.path.isdir(os.path.join(att, folderName)):
                foundOne = True
                break
        if not foundOne:
            return False
        return True
    
    
    def is_meat_installed(self):
        """Returns whether the meat of this pigment or similar to it is installed"""
        (md1, md2) = (hashlib.md5(), hashlib.md5())
        try:
            f1 = glob(self.attPath + "/*") 
            f2 = glob("/usr/share/icons/%s/*" % self.attDirname)
            # FIXME: icons
            if "cursors.theme" in f2:
                f2.remove("cursors.theme")
            if "cursors" in f2:
                f2.remove("cursors")
        except:
            return False
        for mm, ff in ((md1, f1), (md2, f2)):
            for af in ff:
                try:
                    ss = file(af, "rb").read(8096)
                except:
                    return False
            if not ss:
                break
            mm.update(ss)
        return m1 == m2
        
    
    def is_meat_activated(self):
        """Returns whether the meat of this pigment or similar to it is activated"""
        (md1, md2) = (hashlib.md5(), hashlib.md5())
        client = gconf.client_get_default()
        try:
            f1 = glob(self.attPath + "/*")
            f2 = glob(os.path.join(self.type.publicBaseDir,client.get_string("/desktop/gnome/interface/icon_theme"))) 
        except:
            return False
        for mm, ff in ((md1, f1), (md2, f2)):
            for af in ff:
                try:
                    ss = file(af, "rb").read(8096)
                except:
                    return False
            if not ss:
                break
            mm.update(ss)
        return m1 == m2
    
    def generate_preview(self):
        if len(self.attPath) < 1:
            return None
        import theme_preview
        pb = theme_preview.icon_generate(self.attPath)
        if pb is None:
            return None
        else:
            self.preview = pb
            return pb
    
    def does_activation_require_root(self):
        """Returns whether the activation requires root rights.
        If it does, the pigment object will need a pexpect bash shell as root
        to be passed to some of its methods"""
        return False
    
    def get_display_data(self, index=0):
        """Returns the object of index to be added to a gtk.ListStore, this
        could be a string, a gtk.gdk.Pixbuf or a custom widget, it should
        be rendered using type.create_cell_renderer"""
        return

def main():
    wp = Icons()
    print wp.information_xml().toxml()

if __name__ == "__main__":
    main()
